# How to use CPBXAPI libaries

The CLI cpbxapi version use a library written in PHP and Javascript.

This library can be used in you own software directly

## Using cpbxapi_lib with PHP

require the cpbxapi_cli.php library by doing: 

```
require_once("/usr/share/cpbxapi/php/cpbxapi_lib.php");
```

You can then build a new cpbx object using the constructor: 
```
$api = new CPBXApi($domain, $port, $ssl, $appkey, $user, $password, $sessionid);
```

The constructor accept these arguments: 
- domain: this is the IP or domain name of the server.
- port: this is the port of connection (usually 80 or 443)
- ssl: set to true to connect to https, false otherwise. if you don't know, try "false"
- appkey: this is the appkey of your software. please check cpbx api documentation here: https://docs.google.com/document/d/1QveG5lmYtuej58cesWy-ZiXpSOzA-yjoZMLiobR5u3g
- user: this is the username to access api. this is optionnal
- password: password associated to username (optionnal)
- sessionid: if you dont want to use user/password, you can pass the current sessionid 

Once a new instance is created, you must call first the `connect` methode. this method return true/false if success/failure
```
if (!$api->connect()) {
  echo "Failed to connect";
}
else {
  echo "Good, continue !";
}
```

To call any API, you can now call `sendToApi` method:
```
$api->sendToApi($request, $data, $ignoreToken);
```

This method accept these arguments: 
- request: this is the request you want to call on api. example: find_extension
- arguments: associative array of arguments you must pass to API. For example: array("extension_id" => 1, "name" => "Olivier")
- ignoreToken: (optional) set this to true to call the request without checking token status. Setting true, CPBXApi will not check token validity before trying to call the api. Default value is false


### Example with PHP

```
<?php
require_once("/usr/share/cpbxapi/php/cpbxapi_lib.php");

$api = new CPBXApi("127.0.0.1", "80", false, "a1802ad3c1a776222389f6101acade39ac9d3c830c3157ac2b4b1d637d071012bef2063a7893d944e3ba75b0345430e45c616b08902be71295a018a9f64db23c", "olivier", "mysuperpassword", null);

if (!$api->connect()) {
  echo "Failed to connect";
  exit(1);
}

$response = $api->sendToApi("find_extension", array("name" => "olivier"));
echo json_encode($response->data[0]->extension);
exit(0);
```

